GitRepository class abstract

Minimal repository contract required by GitOperationService.

Constructors

GitRepository()

Properties

currentBranchOnDisk String?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getExpandedPath(void log(String message)) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited